Module lifecycle

Module lifecycle 

Modules

adapters
mapping

Structs

LifecycleEngine
Stateless decision engine for order lifecycle state machines.
SnapshotDelta
The result of converting a cumulative snapshot into an incremental delta.

Enums

LifecycleTransition
A state-mutating action the consumer wants to apply to an order.
TerminalStatus
Terminal state of a DeFi order lifecycle.
TransitionDecision
Result of LifecycleEngine::decide_transition.