pub struct SnapshotDelta {
pub delta: i64,
pub regression: bool,
}Expand description
The result of converting a cumulative snapshot into an incremental delta.
delta is always >= 0. If the snapshot regressed (new total < stored total),
delta is clamped to 0 and regression is set to true.
Fields
delta: i64Non-negative increment to add to the stored total.
regression: booltrue when the snapshot total was less than the stored total.