Modules
Structs
- Lifecycle
Engine - Stateless decision engine for order lifecycle state machines.
- Snapshot
Delta - The result of converting a cumulative snapshot into an incremental delta.
Enums
- Lifecycle
Transition - A state-mutating action the consumer wants to apply to an order.
- Terminal
Status - Terminal state of a DeFi order lifecycle.
- Transition
Decision - Result of
LifecycleEngine::decide_transition.