pub enum CorrelationOutcome {
NotRequired,
Correlated(Vec<String>),
Uncorrelated {
reason: String,
},
}Expand description
Whether (and how) an event was correlated to an order PDA.
Variants
NotRequired
Correlation is not meaningful for this event type
(e.g. Kamino UserSwapBalancesEvent is diagnostic-only).
Event was successfully matched to one or more order PDAs.
Event is the kind that should correlate, but context was missing
(e.g. Kamino OrderDisplayEvent without pre-fetched PDAs).